# 基于ESP32的智能巡检轮足机器人

# 最终方案

参考方案：https://github.com/MuShibo/Micro-Wheeled_leg-Robot

复刻说明：https://docs.qq.com/doc/DR0N1SXhrb1d0Vmd3

## 硬件设计

设计工具：嘉立创EDA

主控电路：主控芯片ESP32，磁编码器AS5600，陀螺仪MPU6050。

驱动电路：无刷电机驱动L6234PD013TR，总线舵机驱动SN74LVC1G126DBVR。

电源管理：2S航模电池7.4V 1100mah，DC-DC电源芯片MP2225GJ降压到5V，再线性稳压器AMS1117降压到3V3。

## 机械结构

设计工具：Fusion360

结构组成：

    闭合四杆结构：由四根连杆（L0-L4）通过铰接点形成闭合链条，允许相邻杆件相对旋转。

    L4：与机身刚性连接的PCB（核心支撑结构）

    L1：大臂（主动控制杆）

    L3：传动筋（传递动力与协调运动）

    L0与L2：一体式小臂（辅助支撑与运动执行）

    运动自由度：通过控制任意铰接点（如L1-L4连接点），可联动调节整体机构状态，实现机器人高度、倾斜角度及转向的灵活调整

设计考量：

    长度比例优化：L0 = L1：确保机体重心经过车轮轴，提升行走稳定性。L4 > L2：减小角度变化（如∠φ）对机身姿态（L4角度）的敏感度，降低陀螺仪数据波动，提高控制精度。

    综合设计考量：稳定性：铰接点布局需减少机身高度变化时的角度扰动。运动干涉：避免机械部件在运动中的碰撞问题。美观性：兼顾功能性与结构设计的简洁性。

应用优势：

    地形适应性：通过四杆联动机制，增强机器人对复杂地形的通过能力（如崎岖路面、台阶等）。

    控制简化：仅需驱动少数铰接点即可实现多自由度调节，降低控制复杂度。

    低成本高效能：结构简单可靠，制造成本低，且易于维护，适用于规模化机器人应用。

    该四杆机构通过几何约束与动态联动，平衡了轮式机器人的高速运动能力与足式机器人的地形适应能力，是轮足融合机器人设计的典型解决方案。


## 软件设计

设计工具：PlatFormIO

环境配置：Arduino1.8.18，ESP32 2.0.3

库调用：Servo_STS3032，SimpleFOC，Bluepad32

实现功能：无刷电机的FOC算法，总线舵机驱动，MPU6050数据采集，双轮足运动系统的姿态解算，蓝牙手柄控制。

实现流程：

    初始化：电机三相驱动引脚配置，总线舵机位置矫正，PID参数配置，陀螺仪初始化，数据返回滤波。

    循环：无刷电机控制，舵机控制。

    中断：蓝牙手柄控制，倾斜急停，电压检测。

## 项目特点
双轮足运动系统:

设计优势: 结合轮式与足式机器人优点，既能在平坦地面快速移动，又能跨越小障碍或楼梯，适应复杂地形。控制技术: 采用永磁同步电机 FOC 控制，确保行走稳定性与平衡性，降低能耗，提高续航能力。蓝牙手柄控制:操作便捷性: 通过蓝牙手柄实现远程控制，方便用户操作与调试，提升机器人实用性。

高性价比设计:硬件选型: 采用成熟且性价比高的硬件组件，降低制造成本。软件开发: 基于开源平台与算法，减少开发成本与周期。

稳定可靠:机械结构: 四杆机构设计简单可靠，制造与维护成本低。控制系统: 基于 ESP32 与 FOC 算法，实现精确控制与稳定运行。


